package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`/@`!````X"5```````!``````````%BS````
M`````````$``.``-`$``'``;``8````$````0`````````!``$```````$``
M0```````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#0```````&`-````````<`````````!P``````````0`````````!````
M!`````````````````!``````````$```````#@:````````.!H`````````
M$`````````$````%`````"``````````($`````````@0```````[3X`````
M``#M/@`````````0`````````0````0`````8`````````!@0````````&!`
M``````#(10```````,A%`````````!`````````!````!@```&"M````````
M8+U```````!@O4```````)@$````````Z!0`````````$`````````(````&
M````<*T```````!PO4```````'"]0```````(`(````````@`@````````@`
M````````!`````0````X`P```````#@#0```````.`-```````!`````````
M`$``````````"``````````$````!````'@#````````>`-```````!X`T``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`T```````#@#0```````0`````````!```````````@`````````4.5T9`0`
M``"`GP```````("?0```````@)]```````#4`````````-0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````8*T```````!@O4```````&"]0```
M````H`(```````"@`@````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!0````#````
M1TY5`'_`!L.(LGEOC/^_(Z-P:_.'"IYU!````!`````!````1TY5```````#
M`````@``````````````$0```$@````"````!P```)J5@``)8!1("(X408J$
M`.@`````2````$L```!.````3P```%4```!6````5P````````!9````````
M`%H```!;````7````%T``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\
M(?_D#MEQ6!SB1\8!L@&+;ZQ+X\#"Y3\LNN.2?/NA;&!K"4/69Z_,9D)%U>R)
M!W#3,V+;[0TZEPM_J9R;X:<""J/@^TD`````````````````````````````
M````````!`$``!(`````````````````````````E@```!(`````````````
M````````````+P(``!(`````````````````````````I@(``!(`````````
M````````````````ZP(``!$`````````````````````````BP$``!(`````
M````````````````````F`(``!(`````````````````````````:0(``!(`
M````````````````````````&@$``!(``````````````````````````0``
M`"``````````````````````````Q0$``!(`````````````````````````
M\P(``!(`````````````````````````%@(``!(`````````````````````
M````X0(``!(`````````````````````````H@$``!(`````````````````
M````````2P$``!(`````````````````````````MP```!(`````````````
M````````````.P$``!(`````````````````````````\P$``!(`````````
M````````````````$`(``!(`````````````````````````+0$``!(`````
M````````````````````&P(``!(`````````````````````````0P(``!(`
M````````````````````````Z0(``!$`````````````````````````TP,`
M`!(`````````````````````````$````"``````````````````````````
MJ0$``!(`````````````````````````"0$``!(`````````````````````
M````"0(``!(`````````````````````````+````"``````````````````
M````````>`(``!(`````````````````````````K`(``!(`````````````
M````````````1@```!(`````````````````````````8P```!8`````````
M````````````````>P$``!(`````````````````````````=@```!(`````
M````````````````````!0,``!(`````````````````````````\P```!(`
M````````````````````````AP```!(`````````````````````````[`$`
M`!(`````````````````````````*`(``!(`````````````````````````
MUP```!(`````````````````````````2@(``!(`````````````````````
M````;0$``!(`````````````````````````^@$``!(`````````````````
M````````GP(``!(`````````````````````````7P$``!(`````````````
M````````````T`(``!(`````````````````````````W`$``!(`````````
M````````````````#@$``!(`````````````````````````M`$``!(`````
M````````````````````R0(``!(``````````````````````````@(``!(`
M````````````````````````=P(``!(`````````````````````````M`(`
M`!(`````````````````````````H@```!(`````````````````````````
ME@$``!(`````````````````````````R@$``!(`````````````````````
M````XP$``!(`````````````````````````6P(``!(`````````````````
M````````D0(``!$`````````````````````````Y@```!$`````````````
M````````````NP(``!(`````````````````````````4P(``!(`````````
M````````````````5`$``!(`````````````````````````5````!(`````
M````````````````````?P(``!(`````````````````````````P@(``!(`
M````````````````````````T@$``!(`````````````````````````/0(`
M`!(`````````````````````````Q0```!(`````````````````````````
MW`,``!(`#@!P7D```````%X`````````'00``!(`#@"03D```````/`+````
M````C`(``!(`#@#@(T```````/P!````````70,``!(`#@"`1$````````4`
M````````>P,``!(`#@"`6D```````.,#````````0P0``!(`#@"01$``````
M`.(!````````#`0``!``&0``PD``````````````````;@,``!(`#@"`1D``
M`````"4`````````D0,``!(`#@#@3$```````'0`````````Z`,``!$`$```
M8$````````0`````````!`0``!(`#@!`0T```````#4`````````&`0``!``
M&0!(TD``````````````````,00``!(`#@"`34````````L!````````]P,`
M`!``&`#8P4``````````````````M0,``!(`#@"P1D```````-0`````````
M*@0``!``&`#XP4``````````````````4`0``!$`&`#PP4````````@`````
M````_0,``!(`#@#@)4```````"8`````````^0,``"``&`#8P4``````````
M````````P0,``!(`#@!@34```````!T`````````GP,``!(`#@#`0T``````
M`+H`````````6@0``!(`#@"01T```````%`%`````````%]?9VUO;E]S=&%R
M=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?
M8W5R<F5N=%]C;VYT97AT`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U
M8W0`4&5R;%]G971?<W8`4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S
M:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7W-V7W-E='!V;@!03%]D;U]U
M;F1U;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`
M4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C
M:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V
M7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y
M<VUA;&QO8P!P97)L7V%L;&]C`%]?<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E
M:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E;C8T`'5N;&EN:P!M
M96UM;W9E`'-T<G1O:P!S=')L96X`<FUD:7(`<F5A9`!?7VUE;6-P>5]C:&L`
M<W1R<W1R`%]?<W1R;F-P>5]C:&L`;6MD:7(`9V5T<&ED`')E861L:6YK`')E
M86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`&QS=&%T-C0`7U]L
M:6)C7W-T87)T7VUA:6X`<W1D97)R`&UE;6-H<@!S=')C:'(`8VQO<V4`;W!E
M;F1I<@!G971U:60`86-C97-S`&UE;6-P>0!S=')C;7``7U]E<G)N;U]L;V-A
M=&EO;@!S=')N8VUP`%]?96YV:7)O;@!?7W)E9VES=&5R7V%T9F]R:P!?7W1L
M<U]G971?861D<@!L:6)P97)L+G-O+C4N-#`N,`!L:6)M+G-O+C8`;&EB8RYS
M;RXV`&QD+6QI;G5X+7@X-BTV-"YS;RXR`&QI8F-R>7!T+G-O+C(`<&%R7V-U
M<G)E;G1?97AE8P!P87)?8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4
M`'!A<E]E;G9?8VQE86X`<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N
M86UE`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])
M3U]S=&1I;E]U<V5D`%]?9&%T85]S=&%R=`!X<U]I;FET`%]?8G-S7W-T87)T
M`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?<V5T=7!?;&EB<&%T:`!P
M87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!'3$E"0U\R+C,`
M1TQ)0D-?,BXQ-`!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R+C,S`$=,
M24)#7S(N,RXR`$=,24)#7S(N,BXU`$=,24)#7S(N,RXT`"]U<W(O;&EB-C0O
M<&5R;#4O-2XT,"XP+W@X-E\V-"UP;&0M;&EN=7@M=&AR96%D+6UU;'1I+T-/
M4D4``````0`!``(``P`#``$``P`"``$``0`#``0``P`#``,``0`!``$``P`#
M``$``@`#``,``P`!``$``P`#``$`!0`#``$``0`!``$`!@`!``$``P`#``$`
M`P`!``,``P`!``,``P`!``<``P`#``4``P`!``$``P`#``(``P`!``,``P`!
M``$`"``)``,``P`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0`!``$``0`!`#H#```0````(````!-I:0T```8`9P0````````!
M``<`,`,``!``````````E)&6!@``"0!Q!```$````+21E@8```@`?`0``!``
M```4:6D-```'`(<$```0````LY&6!@``!0"1!```$````'(9:0D```0`G`0`
M`!````!U&FD)```#`*@$```0````=!EI"0```@"T!````````)"_0```````
M!@````4``````````````)B_0```````!@````D``````````````*"_0```
M````!@````H``````````````*B_0```````!@```!H``````````````+"_
M0```````!@```!X``````````````+B_0```````$@```"(`````````````
M`,"_0```````!@```",``````````````,B_0```````!@```"0`````````
M`````-"_0```````!@```#T``````````````-B_0```````!@```#X`````
M`````````."_0```````!@```$,```````````````#`0```````!P````$`
M``````````````C`0```````!P````(``````````````!#`0```````!P``
M``,``````````````!C`0```````!P````0``````````````"#`0```````
M!P````8``````````````"C`0```````!P````<``````````````##`0```
M````!P````@``````````````#C`0```````!P````L``````````````$#`
M0```````!P````P``````````````$C`0```````!P````T`````````````
M`%#`0```````!P````X``````````````%C`0```````!P````\`````````
M`````&#`0```````!P```!```````````````&C`0```````!P```!$`````
M`````````'#`0```````!P```!(``````````````'C`0```````!P```!,`
M`````````````(#`0```````!P```!0``````````````(C`0```````!P``
M`!4``````````````)#`0```````!P```!8``````````````)C`0```````
M!P```!<``````````````*#`0```````!P```!D``````````````*C`0```
M````!P```!L``````````````+#`0```````!P```!P``````````````+C`
M0```````!P```!T``````````````,#`0```````!P```!\`````````````
M`,C`0```````!P```"```````````````-#`0```````!P```"$`````````
M`````-C`0```````!P```"4``````````````.#`0```````!P```"8`````
M`````````.C`0```````!P```"<``````````````/#`0```````!P```"@`
M`````````````/C`0```````!P```"D```````````````#!0```````!P``
M`"H```````````````C!0```````!P```"L``````````````!#!0```````
M!P```"P``````````````!C!0```````!P```"T``````````````"#!0```
M````!P```"X``````````````"C!0```````!P```"\``````````````##!
M0```````!P```#```````````````#C!0```````!P```#$`````````````
M`$#!0```````!P```#(``````````````$C!0```````!P```#,`````````
M`````%#!0```````!P```#0``````````````%C!0```````!P```#4`````
M`````````&#!0```````!P```#8``````````````&C!0```````!P```#<`
M`````````````'#!0```````!P```#@``````````````'C!0```````!P``
M`#D``````````````(#!0```````!P```#H``````````````(C!0```````
M!P```#L``````````````)#!0```````!P```#P``````````````)C!0```
M````!P```#\``````````````*#!0```````!P```$```````````````*C!
M0```````!P```$$``````````````+#!0```````!P```$(`````````````
M`+C!0```````!P```$0``````````````,#!0```````!P```$4`````````
M`````,C!0```````!P```$8``````````````-#!0```````!P```$<`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!9&?``!(A<!T`O_02(/$",,``````/\URI\``/\ES)\`
M``\?0`#_)<J?``!H`````.G@_____R7"GP``:`$```#IT/____\ENI\``&@"
M````Z<#_____);*?``!H`P```.FP_____R6JGP``:`0```#IH/____\EHI\`
M`&@%````Z9#_____)9J?``!H!@```.F`_____R62GP``:`<```#I</____\E
MBI\``&@(````Z6#_____)8*?``!H"0```.E0_____R5ZGP``:`H```#I0/__
M__\E<I\``&@+````Z3#_____)6J?``!H#````.D@_____R5BGP``:`T```#I
M$/____\E6I\``&@.````Z0#_____)5*?``!H#P```.GP_O___R5*GP``:!``
M``#IX/[___\E0I\``&@1````Z=#^____)3J?``!H$@```.G`_O___R4RGP``
M:!,```#IL/[___\E*I\``&@4````Z:#^____)2*?``!H%0```.F0_O___R4:
MGP``:!8```#I@/[___\E$I\``&@7````Z7#^____)0J?``!H&````.E@_O__
M_R4"GP``:!D```#I4/[___\E^IX``&@:````Z4#^____)?*>``!H&P```.DP
M_O___R7JG@``:!P```#I(/[___\EXIX``&@=````Z1#^____)=J>``!H'@``
M`.D`_O___R72G@``:!\```#I\/W___\ERIX``&@@````Z>#]____)<*>``!H
M(0```.G0_?___R6ZG@``:"(```#IP/W___\ELIX``&@C````Z;#]____):J>
M``!H)````.F@_?___R6BG@``:"4```#ID/W___\EFIX``&@F````Z8#]____
M)9*>``!H)P```.EP_?___R6*G@``:"@```#I8/W___\E@IX``&@I````Z5#]
M____)7J>``!H*@```.E`_?___R5RG@``:"L```#I,/W___\E:IX``&@L````
MZ2#]____)6*>``!H+0```.D0_?___R5:G@``:"X```#I`/W___\E4IX``&@O
M````Z?#\____)4J>``!H,````.G@_/___R5"G@``:#$```#IT/S___\E.IX`
M`&@R````Z<#\____)3*>``!H,P```.FP_/___R4JG@``:#0```#IH/S___\E
M(IX``&@U````Z9#\____)1J>``!H-@```.F`_/___R42G@``:#<```#I</S_
M__\E"IX``&@X````Z6#\____)0*>``!H.0```.E0_/___R7ZG0``:#H```#I
M0/S__U532(/L.(E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(9$B+!"4H
M````2(E$)"@QP.AX____2(LU>9L``$B+/:*;``!(B?+HHCH``$B+!:.;``"`
M.`!U-^A!_?__2(D%^JT``$B)QTB%P`^$@`$``.BI_?__9$B+!"4`````2`,%
M49L``$B+`,:`M@@```!D2(L$)0````!(`P4WFP``2(L`@(@Z!````XM$)!R-
M>`5(8_](P><#Z(+^__],BT0D$$2+3"0<QP5^K0``!````$B)P4B)!6RM``"^
M`0```$F+`$R)RDB)`4B-!?<\``!(B4$(2,?`\,%``$B+`$B)01!(C07A/```
M2(E!&$&#^0%^&P\?0`!)BP3PC7X#2(/&`4AC_TB)!/E,.<YUZ8/"`TB+/2>M
M``!%,<!(C35='@``2&/"2,<$P0````#H/?O__XG#A<!T44B+/0"M``!(C6PD
M).@V_?__,<!(B>Y(C3U-.P``Z.47``!(A<!T.DB+/=FL``#HQ/K__^A?_/__
M2(M$)"AD2"L$)2@```!U3$B#Q#B)V%M=PTB+/:^L``#H6OO__XG#ZY](BSV7
MK```2(7_=`?HQ3@``.NS2(T]I#H``$B)[NB$%P``2(D%=:P``$B)QTB%P'25
MZ]GH[OS__[\!````Z,3Z__\/'T``\P\>^C'M28G17DB)XDB#Y/!05$4QP#')
M2,?'X"-``/\5VYD``/1F+@\?A```````\P\>^L-F+@\?A```````D$B-/=&;
M``!(C07*FP``2#GX=!5(BP5NF0``2(7`=`G_X`\?@`````###Q^``````$B-
M/:&;``!(C36:FP``2"G^2(GP2,'N/TC!^`-(`<9(T?YT%$B+!369``!(A<!T
M"/_@9@\?1```PP\?@`````#S#Q[Z@#UEFP```'4354B)Y>AZ____Q@53FP``
M`5W#D,-F9BX/'X0```````\?0`#S#Q[ZZXIF+@\?A```````05=(B?Y,C4<X
M059!54%455-(@>R8`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-C"2`````
M2(G7#Q^``````$&+`$V+$$B#QQ!)@\`(#\B)P$R)T4B)1_!,B=!(P>D@2,'H
M*$G!ZC@E`/\``$P)T$F)RDC!X0A)P>(8@>$``/\`18G23`G02`G(2(E'^$PY
MSW6M9@]O3"009@]O7"0@2(U$)&A(@<)H`@``9@]O5"0P9@]O+9=W```/'X``
M````\P]O`&8/;^)F#V]0V$B#P!!F#^](B&8/[\)F#^_!9@]OR&8/<]`?9@]S
M\0%F#^O!9@]ORV8/;]QF#]O%#RE`"$@YT'6[3(L.3(M>$$B+?B!(BUX83(G(
M3(G*2(MN"$B+3"0(2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4.)EY@EI,B=A(
M,=A((>A(,=B-/`)(B>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!ZAM!B=!,,<!,
M(<A,,=A(`<A(B?E(P>$%3`G13(M4)!!$C20(3(G(3(G)2,'I`DC!X!Y/C903
MF7F"6DV)Y4@)R$G![1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD&$$!
MTDB)^DC![P)(P>(>18G23XV$*)EY@EI("?I-B=5(,=")UTPAX$G![1M(,<A,
M`<!-B=!)P>`%30GH3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@
M38G%2#'"2<'M&T&)Q$PATD@Q^D@!RDR)P4C!X05,">E,BVPD*`'13(G22<'J
M`DC!XAZ)R4J-O"^9>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!
MYP5,">],BVPD,`''3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M
M&T&)P$@ARDPQTDP!XDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!Z0)(P>(>18GD
M3XV4*IEY@EI("<I-B>5(,=!)P>T;B=%((?A,,<!,`=!-B>))P>(%30GJ3(ML
M)$!!`<)(B?A(P>\"2,'@'D6)TD^-A"B9>8):2`GX38G52#'"2<'M&XG'3"'B
M2#'*3`'"38G02<'@!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%B<!*C8PIF7F"
M6DP)XDV)Q4@QT$G![1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI3(ML)%`!P4R)
MT$G!Z@)(P>`>B<E*C;POF7F"6DP)T$F)S4@QPDG![1M!B<),(<),,>)(`?I(
MB<](P><%3`GO3(ML)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"6DP)PDF)_4@Q
MT$G![1M!B=!((<A,,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(B<A(P>`>2,'I
M`D6)Y$^-E"J9>8):2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'238GB2<'B!4T)
MZDR+;"1H00'22(GZ2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@QT$G![1N)
MUTPAX$@QR$P!P$V)T$G!X`5-">A,BVPD<$$!P$R)X$G![`)(P>`>18G`2HV,
M*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)Z4R+;"1X
M`=%,B=)(P>(>2<'J`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G23"'`3#'@
M2`'X2(G/2,'G!4P)[TR+K"2``````<=,B<!)P>@"2,'@'HG_3XVD+)EY@EI,
M"<!)B?U(,<))P>T;08G`2"'*3#'23`'B28G\2<'D!4T)[$:-+")(B<I(P>D"
M3(ND)(@```!(P>(>2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%((?A,,<!,`=!-
MB>I)P>(%30GB3(ND))````!!`<)(B?A(P>`>2,'O`D6)TD^-A""9>8):2`GX
M38G42#'"2<'L&XG'3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!PDV)Z$G![0))
MP>`>08G430GH3(NL))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q^$G![1M(`<A,
MB>%(P>$%3`GIB<E(`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)P$DQRD0QTDR+
ME"2@````2HV\%Z'KV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'73(GB2,'B
M'DG![`)!B?I,`X0DJ````$P)XDF)S(G)2`.,)+````!),=1$,>!-C:0`H>O9
M;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)Z$F)U8G2
M2`.4)+@```!),<5$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,
MB=%)P>H"2,'A'D2)[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;
M2,'B!4P)THG220'43(G"2<'H`DC!XAY%B>),"<))B<A(`X0DP````(G)23'0
M2`.,),@```!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(
MP>\"2,'@'D6)Z$@)^$B)UXG22`.4)-````!(,<=$,>=,C:0YH>O9;DR)P4R)
MQTC![QM(P>$%2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)-@`
M``!),<I%,>I.C:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"
M2,'B'D6)ZDP)PDF)R(G)23'02`.,).````!%,>!.C:0`H>O9;DR)T$V)T$G!
MZ!M(P>`%3`G`B<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4).@```!(
M,<=$,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A
M'D2)[TP)T4F)PHG`2`.$)/````!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(
MP>(%3`G2B=))`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'K
MV6Y,B=!-B=!(P>`%2<'H&T@#C"3X````3`G`B<!)`<5(B?A(P>\"2,'@'D6)
MZ$@)^$B)UXG22`.4)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC![QM(P>$%
M2`GYB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!``!),<I%,>I.
MC:P2H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B'D6)ZDP)
MPDF)R(G)23'013'@3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#C"00`0``
MB<!)`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(,<=$,>],C:PY
MH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)
MPHG`2`.$)"`!``!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))
M`=1,B<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,B=!-B=!)
MP>@;2,'@!4P)P(G`20'%2(GX2,'@'DC![P)%B>A(`XPD*`$``$@)^$B)UXG2
M2`.4)#`!``!(,<=$,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG38G42<'J
M`DG!Y!Z)_TT)U$F)PD@!^8G`33'BB<](`X0D.`$``$4QZDF)_4Z-E!*AZ]EN
M2(GZ2<'M&TC!X@5,">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)Y$DQT$F)
MUD&)U40QP4V)T$B-C`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY2,'O`KC<
MO!N/2,'A'D@)^4D)SHG/2"'Z32'620G62(N4)$`!``!(`<),`>)-B<1,`?)-
MB<9)P>0%2<'N&TT)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^
M3"'!3`GQ3(NT)$@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!
MS4R)P4G!Z`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%`!``!)`<9,
M`?=-B>Y(`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)
MUD&)U$TAQDPAZ4P)\4R+M"18`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-
M"?))B=9!`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"1@
M`0``20'&30'P38G63`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"2,'B'D6)
MP$@)^D@)T4F)UHG732'N3"'13`GQ3(NT)&@!``!)`<9-`?1-B<9,`>%-B<1)
MP>X;2<'D!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.32'&3"'2
M3`GR3(NT)'`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDC!
MXAY)P>@"18GM3`G"2`G128G608G032'63"'A3`GQ3(NT)'@!``!)`<9,`?=-
MB>Y(`?E,B>])P>X;2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)X4&)S$D)
MSDTA[DPAXDP)\DR+M"2``0``20'&30'R28G^3`'228GZ2<'N&TG!X@5-"?)!
M`=),B>I)P>T"2,'B'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+M"2(`0``
M20'&30'P38G63`'!38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"2,'A'D6)
MP$@)^8G/20G.32'62"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,`>)-B<1)P>X;
M2<'D!4T)]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^3"'!3`GQ
M3(NT))@!``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!S4R)P4G!
MZ`)(P>$>18GM3`G!08G(20G.32'F3"'"3`GR3(NT)*`!``!)`<9,`?=-B>Y(
M`?I,B>])P>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)UD&)U$TA
MQDPAZ4P)\4R+M"2H`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-"?))B=9!
M`<I,B>E)P>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2P`0``20'&
M30'P38G63`'"38G02<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)P$@)^D@)
MT4F)UHG732'N3"'13`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-B<1)P>X;2<'D
M!4T)]$F)UD$!S$R)T4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'23`GR3(NT
M),`!``!)`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!Z`)(P>(>
M18GM3`G"2`G128G008G732'03"'A3`G!3(N$),@!``!)`<!,`<=-B>A(`?E,
MB>])P>@;2,'G!4P)QT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)^4PAZ4PA
MXD@)RDB+C"30`0``2`'!3`'138G"2`.$)-@!``!(`<I,B<%)P>H;2,'A!4P)
MT8G)2`'*3(GI2<'M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-(>5)"?U*C3PX
M3(G03(N\)/@!``!,`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`2<'H`DC!X!Y!
MB?U)"<"XUL%BRDPQP3'12(N4).`!``!(`<),`>)-B>Q(`<I,B>E)P>P;2,'A
M!4P)X4V)U(G)2<'D'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQU$0QYTR+I"3H
M`0``20'$30'T28G.3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"2<'F'D6)Y$T)
M]4R+M"3P`0``3`'G08G\20'&30'P38G633'N1#'R38GF20'03(GB2<'N&TC!
MX@5,"?*)TDD!T$B)RDC!Z0)(P>(>18G&2`G*1(G138GJ23'23`'Y3(N\)``"
M``!$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!X1Y!
MB?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"00`@``13'H38G520'(3(G12<'M&TD!
MQTC!X05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"``!)`<9,`?)-
MB>9),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!XAY!
MB?Y)"=)$B>))B<R)R4P!^DTQU$R+O"0@`@``13'@38GT20'03(GR2<'L&TD!
MQTC!X@5,">*)TDD!T$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"``!)`<5,`>E-
MB=5),=5$,>]-B>5(`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!X1Y!
MB?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"0P`@``13'038GJ20'(3(GI2<'J&TC!
MX05,"=&)R4D!R$R)X4C!X1Y)P>P"18G"20''3`GA3(ND)"@"``!)`<1,`>)-
MB?1),<Q$,>=-B=1(`==,B=))P>P;2,'B!4P)XHG22`'73(GJ2<'M`DC!XAY!
MB?Q)"=5$B?))B<Z)R4TQ[DP!^DR+O"1``@``13'P38GF20'03(GB2<'N&TC!
MX@5,"?*)TDD!T$R)TDG!Z@)(P>(>18G&3`G23(N4)#@"``!)`<),`=%-B>I)
M,=)$,==-B?)(`<],B?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!X1Y!
MB?I)"<Q$B>E)B=6)TDTQY4P!^4R+O"1@`@``13'H38G520'(3(G12<'M&TC!
MX05,">F)R4D!R$R)\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)`<9,`?)-B>9%
MB>1),<Y$,?=-B>Y(`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!XAY!
MB?Y)"=)(BY0D4`(``$@!PDD!U$B)RHG)3#'220''1#'"38GP20'43(GR2<'H
M&TC!X@5,"<*)TDD!U$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"``!)`<5,`>E-
MB=5),=5$,>]-B<5(`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!X1Y!
MB?U)"<Y$B=%)B=*)TDTQ\DP!^4R+O"1P`@``13'B38GL3`'138GJ2<'L&TG!
MX@5-">)-B<1%B=))P>0>3`'12<'H`DD!QTT)X$R+I"1H`@``08G*20'$2`.$
M)'@"``!,`>)-B?1,`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B!4P)XDV)[$G!
M[0))P>0>B=)-">5%B?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)UDP!P$V)Z$P!
MX4F)U$G![AM)P>0%30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQT$0QQTF)R$@!
M^$B)STC!YP5)P>@;`>E!`=I,"<=$`VX@2(E."`'X3(E6&$B)!DB)T$C!Z@)(
MP>`>3(EN($@)T$0!V$B)1A!(BX0DB`(``&1(*P0E*````'422('$F`(``%M=
M05Q!74%>05_#Z(;E__]F#Q]$``!!5T%6055!5%532(/L"$B%_P^$L0```$B+
M!3*"``!,BS!-A?8/A)X````/M@=)B?])B?6$P'0$/#UU544QY$F+'DB%VW0P
M36/D3(GU#Q]``$R)XDR)_DB)W^@RX___A<!U!T*`/",]=$=(BUT(2(/%"$B%
MVW7:2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q!#[9$)`%)@\0!A,!T
M!#P]=>Y%*?SKE&8/'T0``$PI]4J-7",!2,']`T&);0#KM&8/'T0``#';ZZH/
M'T``4TB)^TB![*````!D2(L$)2@```!(B80DF````#'`2(GFZ+KD__^%P'4V
MBU0D&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)W^C_Y/__A<`/E,`/
MML#K!P\?1```,<!(BY0DF````&1(*Q0E*````'4)2('$H````%O#Z"WD__]F
M9BX/'X0``````&:0055!5%532('LJ````&1(BP0E*````$B)A"28````,<!(
MA?]T"(`_`$B)^W4K2(N$))@```!D2"L$)2@````/A2,!``!(@<2H````6UU!
M7$%=PV8/'T0``.C#XO__2(G%2(7`=,A(B>_HH^3__TB%P`^$L@```(!X$RY,
MC6`3=1!!@'PD`0!TW0\?A```````@'@3+@^$I@```$B)W^A>XO__3(GG28G%
MZ%/B__]!C7P%`DAC_^B&X?__38GA28G8O@$```!)B<5(B<<QP$C'PO____](
MC0V)(```Z-#C__],B>](B>;H)>+__TR)[X/X_W00BT0D&"4`\```/0!```!T
M7>AXX?__3(GOZ.#A__](B>_H^./__TB%P`^%5?___P\?@`````!(B>_H<./_
M_TB)W^A8X?__Z?#^__\/'P!!@'PD`2X/A4[___]!@'PD`@`/A`W____I/?__
M_P\?`.B;_O__ZZ'HM.+__P\?0`!!5T%6055!5%5(B?532(G[2(/L*&1(BP0E
M*````$B)1"08,<`QP(`^/0^4P$@!Q4B)[^A9X?__2(UT)!1(B=])B<0QP.CG
M_/__2(7`#X0&`0``2(G'28G%Z#/A__],.>`/@](```!(8TPD%$R+-0Y_``!,
MC3S-``````^V`X3`#X2C`0``/#T/A)L!``!(B=@/ME`!2(/``832=`6`^CUU
M[T@IV$B838LN2HU\(`+H'>#__TT!_4F)10!(A<!T4DF+!DB-2P%*BQ0X#[8#
MB`(\/70BA,!U#>L<#Q^``````#P]=!$/M@%(@\(!2(/!`8@"A,!UZ\8"/3'`
M9@\?1```#[9,!0"(3`(!2(/``83)=>](BT0D&&1(*P0E*`````^%%P$``$B#
MQ"A;74%<05U!7D%?PP\?0``QP&8/'T0```^V5`4`08A4!0!(@\`!A-)U[NN]
M#Q]``$R+-2%^``!-BP9)@S@`#X3#````3(G`13'M9@\?1```2(/`"$2)ZD&#
MQ0%(@S@`=>^-<@-(8_9(P>8#BP5WD```A<!U8TB)]TR)1"0(QP5AD````0``
M`.@<W___2(G'2(7`#X11____26/-2(MT)`A,C3S-`````$R)^NAXX/__28D&
M2(G'08U%`42);"042)A(QP3'`````.F$_O__9BX/'X0``````$R)Q^A8X?__
M28D&2(G'2(7`#X3Z_O__26/-3(T\S0````#KN@\?0``QP.EW_O__OA````!%
M,>WI5____^AOX/__9F8N#Q^$```````/'T``056Z_P\``$%454B)]5-(B?M(
MC3V2'0``2('L&!```&1(BP0E*````$B)A"0($```,<!)B>1,B>;HH]___X7`
M?A*)P8/H`4ACT(`\%`!U487`=45D2(L$)0````!(`P7U?```2(GJ2(G>2(LX
MZ&_>__](BX0D"!```&1(*P0E*````'572('$&!```%M=05Q!7<-F#Q]$``")
MP68/'T0``$QCZ;XO````3(GG3(GJZ&W=__](A<!TFV1(BP0E`````$@#!9!\
M``!,B>E,B>)(B=Y(BSCH]][__^N6Z(#?__](@^P(9$B+!"4`````2`,%9'P`
M`$B+%65\``!(C0VN6P``2(TUL!P``$B+.$B#Q`CI"^#__V9F+@\?A```````
M4V1(BP0E`````$@#!2=\``!(BSA(B</HI/___TB+.TR-!?\=``!;2,?"@%I`
M`$4QR4R)P4B--7H<``#I,-[__U532('L*"```&1(BP0E*````$B)A"08(```
M,<!(B>-(C:PD$!```.ATW?__2(T-5QP``+H!$```2(G?08G`3(T-$!P``+X!
M````,<#H/]___[H`$```2(GN2(G?Z!_>__\QR87`>"Z->`%(B<-(8__HJ]S_
M_TB)P4B%P'082&/;2(GN2(G'2(G:Z%+?___&!!@`2(G!2(N$)!@@``!D2"L$
M)2@```!U#4B!Q"@@``!(B<A;7</H1M[__V8/'T0``.D[____9F8N#Q^$````
M``!!5T%6055!5$F)_$B-/;8;``!52(GU4TB![+@0``!D2(L$)2@```!(B80D
MJ!```#'`2(UT)`SH=?C__[XO````3(GG2(G#Z)7=__](A<!T0#'`3(GF2(T]
M=1L``.@?^___3(G@2(N4)*@0``!D2"L4)2@````/A6(!``!(@<2X$```6UU!
M7$%=05Y!7\,/'P!,B>=,C2U$&P``Z''<__],B>Y(B>]!B<;HH]W__TF)QTB%
MP'2;08/&`4&`/P`/A,4````/'T0``$B%VW033(G^2(G?Z&C=__^%P`^$B```
M`$R)_^@HW/__ZPEF#Q]$``#&`@")P8/H`4ACT$P!^H`Z+W3M1`'Q@?G_#P``
M#X\^____N@`0``!-B?B^`0```#'`2(VL)*````!(@^P(2(T-DAL``$%43(T-
MHQH``$B)[^A[W?__2(UT)"!(B>_HSMO__UI9A<!U$(M$)"@E`/```#T`@```
M=$A,B>XQ_^C>W/__28G'2(7`#X32_O__08`_``^%0/___TB%VW0%@#LN=!9,
MC3TM&@``N0$```#I8/___P\?1```@'L!`'2ZZ^*^`0```$B)[^@3W?__A<!U
MITB)[DB-/08:``#HL/G__TB)[^@XW/__Z8?^___H3MS__V9F+@\?A```````
M#Q\`#[8'2(GZA,!T%V8/'T0``$B#QP$\+P^V!T@/1->$P'7O2(G0PV9F+@\?
MA```````2(7_#X2_````4X`_`$B)^P^$B@```.C5VO__2(U4`_](.=-R%.LO
M9@\?A```````2(/J`4@YTW1W@#HO=/)(.=-R#NL1#Q\`2(/J`4@YTW1?@#HO
M=?)(.=-U"NM3#Q\`@#HO=0E(@^H!2#G3<O)(*=HQP$B-2@)(@?D`$```=QA(
M@\(!N0`0``!(B=Y(C3W=>@``Z`C9__];PV8/'T0``$B-/?\8``!;Z4/;__\/
M'P"`.R]TZTB-/009``!;Z2[;__]F#Q]$``!(C3W7&```Z1S;__]F9BX/'X0`
M`````)!!5T%6055!5%5(C2W2&```4TB#[$AF#V\%@U<``&1(BP0E*````$B)
M1"0X,<`QP$B-7"0,#RE$)!!F#V\%;U<``&:)1"0P#RE$)"`/'T0``#'`2(G>
M2(GOZ%/U__](A<!T/DB+!9=W``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/
M'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(TM1!@``&8/'X0`````
M`#'`2(G>2(GOZ//T__](A<!T/DB+!3=W``!(8U0D#$B+`$B-!-!(BU`(2(D0
M2(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(TM[!<``&8/
M'X0``````#'`2(G>2(GOZ)/T__](A<!T/DB+!==V``!(8U0D#$B+`$B-!-!(
MBU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(TM
ME1<``&8/'X0``````#'`2(G>2(GOZ#/T__](A<!T/DB+!7=V``!(8U0D#$B+
M`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?
M1```2(TM/!<``&8/'X0``````#'`2(G>2(GOZ-/S__](A<!T/DB+!1=V``!(
M8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U
M\.NV9@\?1```3(TE[!8``&8/'X0``````#'`2(G>3(GGZ'/S__](A<!T/DB+
M!;=U``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(
MB1!(A=)U\.NV9@\?1```3(TE018``&8/'X0``````#'`2(G>3(GGZ!/S__](
MA<!T/DB+!5=U``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``````2(M0
M$$B#P`A(B1!(A=)U\.NV9@\?1```3(TU.!8``&8/'X0``````#'`2(G>3(GW
MZ+/R__](A<!T/DB+!?=T``!(8U0D#$B+`$B-!-!(BU`(2(D02(72=,\/'X``
M````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(TMXA4``&8/'X0``````#'`
M2(G>3(GOZ%/R__](A<!T/DB+!9=T``!(8U0D#$B+`$B-!-!(BU`(2(D02(72
M=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(T]C!4``&8/'X0`
M`````#'`2(G>3(G_Z//Q__](A<!T/DB+!3=T``!(8U0D#$B+`$B-!-!(BU`(
M2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```3(T]RA0`
M`&8/'X0``````#'`2(G>3(G_Z)/Q__](A<!T/DB+!==S``!(8U0D#$B+`$B-
M!-!(BU`(2(D02(72=,\/'X``````2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```
M2(G>2(T]TQ0``.A!\?__2(7`=`U(B<9,B>\QP.C_\___,<!(B=Y(C3W!%```
MZ![Q__](A<!T$4B)QDB-/;\4```QP.C8\___2(G>2(T]N10``#'`Z/?P__](
MB<9(A<!T.DR)YS'`Z+7S__\QP$B--<,4``!(B>_HI//__TB+1"0X9$@K!"4H
M````=5](@\1(6UU!7$%=05Y!7\,QP$B)WDB-/704``#HI/#__TB%P'0/2(G&
M3(GW,<#H8O/__^NK2+A005)?0TQ%04@Y1"0A=9IF@7PD*4X]=9%(C70D*TR)
M]S'`Z#?S___K@.C@U?__2(/L&&1(BP0E*````$B)1"0(BP7P=```@_C_=!M(
MBU0D"&1(*Q0E*````'5"2(/$&,-F#Q]$``!(C70D!$B-/8L3```QP.@5\/__
M2(G",<!(A=)T$@^V`CPP#Y7"A,`/E<`/ML`AT(D%FW0``.NNZ&S5__]F9BX/
M'X0``````)!(@^P(Z)?5__^)Q^@`U/__2(7`=`-(BP!(@\0(PP\?`$%5051,
MC24:%```54B)_4R)YU-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z(_O__](
MA<!T"(`X`$B)PW4R2(M$)`AD2"L$)2@````/A;0```!(B>Y(@\083(GG,<!;
M74%<05WI)_+__P\?@`````!(B>Y(B<?H)=3__TB%P'0@2(M$)`AD2"L$)2@`
M``!U=DB#Q!A;74%<05W##Q]$``!(B>_H>-/__TB)WTF)Q>AMT___28U\!0+H
MH]+__TB#[`A)B>B^`0```%-(Q\+_____2(G'28G%3(T-$!(``$B-#?$2```Q
MP.CDU/__6%I(BT0D"&1(*P0E*````'4(3(GNZ4_____H-=3__P\?1```05=(
MC0V7$@``2(T5H1(``$F)_T%69D@/;L%(C0TX$@``2(T]H!$``$%505154TB!
M[*B!``!D2(L$)2@```!(B80DF($``$B-!7D1``!(C6PD/$C'1"10`````$C'
MA"2H`````````$B)[DC'1"1P`````&9(#V[H2(T%)A(``&8/;,5F2`]N\$B-
M!1X2```/*40D0&9(#V[!9D@/;OA(C0W1$0``9@]LQDB-!082```/$80DB```
M`&9(#V[!9D@/;N@QP&8/;,</$80DF````&9(#V["9@]LQ0\I1"1@Z,WM__](
MA<!T#(`X`$B)PP^%A`0``#'`3(UD)&#HT/W__TB)PTB%P`^$_`$``$B)W^C\
MT?__2(U\``'H,M'__T0/M@-)B<9)B<5%A,!T.4R-)8L1```/'T``10^VP$R)
M]TR)X;X!````2,?"_____S'`2(/#`4F#Q@+H8]/__T0/M@-%A,!UTDR-I"2`
M````2(T]ZQ```.L79@\?A```````28M\)`A)@\0(2(7_=#I(B>XQP.@8[?__
M2(G#2(7`=."`.`!TVTB)Q^C3[?__A<!TSTB)W^A7TO__28G$2(7`=3\/'X``
M````2(U<)$!,BR--A>1T*T&`/"0`#X2P`0``3(GGZ)CM__^%P`^%@`$``$R+
M8PA(@\,(387D==@/'P!,B>?H"-'__TR)[TB)P^C]T/__C9P#!`0``$ACVTB)
MW^@KT/__055-B>"^`0```$F)QDB-!900``!,C0V@#P``2,?"_____U!(C0UU
M$```3(GW,<#H9]+__[[``0``3(GWZ,K2__]!6$%9@_C_=1+HC-'__T2+"$&#
M^1$/A<D"``!,C:0DL````$R)]TR)YNC,T?__08G%A<!U%XN$),@````E`/``
M`#T`0```#X3F````2(L%AVX``$F+#TV)\$B-%;H0``"^`0```$B+.#'`Z"O/
M__\QVTB+A"28@0``9$@K!"4H````#X7]"```2('$J($``$B)V%M=05Q!74%>
M05_##Q]$``!)BSPD2(7_="(QP$B)[NB5Z___2(7`=`6`.`!U,TF+?"0(28/$
M"$B%_W7>OPT```!(C1U:#P``Z`S/__]!N%,```!)B<9)B<7IV/W__P\?`$B)
MQ^BPT/__2(G#2(7`=+WIG_W__P\?`$R)YTB#PPCHE-#__TF)Q$B%P`^$1?[_
M_^ES_O__#Q\`13'DZ6C^__^+A"3,````B00DZ,G0__\Y!"0/A0+___^+A"3(
M````)?\!```]P`$```^%Z_[__TB)W^B!SO__2(GN2(T]^0X``$B)PS'`Z,WJ
M__](A<`/A,0!``!(B<?H'-#__TF+/TB)QN@!\O__2(G%2(7`#X2E`0``2(GO
MZ/W.__](B<*#^`-^/4B82(TULPX``$B)%"1(C7P%_.@.T/__A<!U(DB+%"2#
M^@0/A&,&``"-0OM(F(!\!0`O#X13!@``#Q]$```QP.CQ^?__A<!U%$B)[S'V
MZ!//__^)QX7`#X5!`0``2(TU&0X``$B-/9H-```QP.CT[/__2(TM@@X``$R-
M)60.``#H,<[__U5(Q\+_____38GP4$R-#2X-``"^`0```$B)WTB-#2\.```Q
MP.CXS___6%KK1@\?0`#H*\___X,X$75*Z/'-__]!@\4!2(/L"$V)\%5,C0WN
M#```3(GAO@$```!!54C'PO____](B=]0,<#HLL___TB#Q""^P`$``$B)W^@1
MT/__@_C_=*Q,B??HU,W__TB)WDB-/9(,```QP.A#[/__2(G?Z*OY___IC?W_
M_TB+!>]K``!)BP]-B?!(C17B#0``O@$```!(BS@QP.B3S/__Z6/]__]F#Q]$
M``!(B<?H</G__TB+A"28@0``9$@K!"4H````#X54!@``2('$J($``$B)WUM=
M05Q!74%>05_I8,[__TF++^E3_O__N@(```!(Q\;N____B00D3(V\))`!``#H
MS,[__XL\)+H&````3(G^Z$S,__^`O"20`0```(L\)'4.@+PDD0$``$,/A&L%
M```QTC'VB3PD,>WHD\[__V8/;P6K2@``,<E(C80DZ````$C'A"3@````````
M``\IA"2P````9@]O!95*``#'A"0H`0````````\IA"3`````9@]O!8I*``!(
MB40D&$B)7"0@2(GK3(ET)"A)B<X/*80DT`````\?1```BSPDN@"```!,B?[H
MJ,O__TF)Q8G%A<`/CBX!``!#C13N26/%3#GR2(F4)-@```!-B?Y(8Y0D*`$`
M`$B#TP!(P>@=2`'82(F$).````"%T@^%HP```(/]/P^."P0``(/M0$&)[4'!
M[09!C5T!2,'C!DP!\P\?1```\T$/;P[S00]O5A!,B>=)@\9`\T$/;U[@\T$/
M;V;P#Q&,).@````/$90D^`````\1G"0(`0``#Q&D)!@!``#H#='__TDYWG6X
M0<'E!D0I[4B+?"082&/5N4@```!(B=[H;,O__XFL)"@!``!,B[0DV````$B+
MG"3@````Z0C___^Y0````$2)Z$R)_BG11#GI#T[!3&/P2(M$)!A(C3P03(GR
MZ'G-__^+A"0H`0``1`'PB80D*`$``(/X0'6N1(GM3(GG1"GU30'^Z(+0___I
M"O___XL\)$B)W4B+7"0@3(DT)$R+="0HZ/3)__](BPPD2(M4)!A(B<A(P>@#
M@^`_C7`!QH0$Z````(!(8\9(`<)(B="#_C@/CMT"``"_0````"GW=`\QTHG6
M@\(!Q@0P`#GZ<O-,B>=(B0PDZ!#0__]F#^_`2(L,)$C'A"08`0````````\1
MA"3H````#Q&$)/@````/$80D"`$```^VP4B)STF)R`^VS4C!X`A)P>@02(GJ
M2(GN2,'O&$@)R$$/MLA(P>X02,'@"$`/MO9(P>H82`G(0`^VSP^VTDR)YTC!
MX`A("<A`#[;-2,'@"$@)R$B)Z0^V[4C!X`A(">A(P>`(2`GP2,'@"$@)T$B)
MA"0@`0``Z&C/__](B[PDN````$B+M"2P````2(N4),````!(BXPDR````$`/
MML=)B?Q)B?U)B?!(B00D2(GX2<'M$$B)]0^V_$B+!"1%#[;M2<'L&$F)UTF)
MT4F)RDF)RTC!X`A%#[;D2<'H&$C![1!("?A)P>\80`^V_DC!X`A)P>D00`^V
M[44/MO],">A)P>H810^VR44/ML!(P>`(2<'K$$4/MM),">!%#[;;3(TE/0D`
M`$C!X`A("?A)B<5(B?`/MOQ,B>A,C:PDB`$``$C!X`A(B<8/ML$/MLU(P>`(
M2`G^2`G(#[;*#[;62,'F"$C!X`A(">Y,"=A(P>8(2,'@"$P)QDP)T$B)-"1(
MP>`(2`G(2,'@"$@)T$C!X`A,"<A(P>`(3`GX3(V\)$`!``!(B40D"(N$)-``
M``!F#V\T)$B)'"1,B?L/R(F$)%`!``!(C80D8`$```\IM"1``0``2(G%28G'
M#Q\`1`^V`TB)[TR)X;X!````2,?"_____S'`2(/%`DB#PP'H8\K__TPY[776
M2(T-K`@``,:$)(@!````2(L<)%%!5TB-#6((``!-B?!(B=\QP+X!````3(T-
M30<``$C'PO_____H(<K__UE>Z7[Z__]-BW\(387_#X2E^?__3(G_Z%7(__](
M@_@##X:3^?__28U\!_Q(C34+"```Z&K)__^%P$D/1._I=_G__TR)\^E6_/__
MNC@```!%,<`I\H/Z"',P]L($#X77````A=(/A%/]___&``#VP@(/A$?]__\Q
M_V:)?!#^Z3O]__\/'X``````B=9(QP``````2,=$,/@`````2(UP"$B#YOA(
M*?`!PH/B^(/Z"`^""?W__X/B^#'`B<>#P`A,B00^.=!R\^GR_/__@+PDD@$`
M`$$/A8?Z__^`O"23`0``0P^%>?K__X"\))0!``!(#X5K^O__@+PDE0$``$4/
MA5WZ__^Z`@```$C'QL;____H[<C__XL\)+HI````3(G^Z&W&__](C05+!P``
M4$%7Z:;^__]F#Q]$``#'``````#'1!#\`````.EQ_/__Z$#(__]!5T%6055!
M5%532(/L*&1(BP0E*````$B)1"08,<!D2(L$)0````!(`P4*90``2(T]W@4`
M`$B+&`^V@[````"(@[$```!(C40D%$B)!"1(B<8QP.AHXO__2(7`=`F`.#$/
MA`H#```QP.BC[/__9$B+!"4`````2`,%NV0``$B+&+D+````N@$```!(C36.
M!@``2(G?Z/?%__](A<`/A!\!``!(BT`02(MH*&1(BP0E`````$@#!7YD``"#
M/>]V```!3(LX#XX*`0``,=OK1V:03(GN3(G_N0(````QTNANR/__38L^2(G&
M2(L%N78``$R-<P%*BSSPZ%3'__^+%:YV``"%P'5[08U&`3G0#XUN`@``3(GS
M,<E(B=I(B>Y,B?]!B=SHJ,;__TB%P'0S3(LH9$B+!"4`````2`,%^&,``$R+
M.$F)QD&+10PE``0@`#T`!```#X5V____28MU$.N(BQ5*=@``B50D#&1(BP0E
M`````$@#!;YC``"+5"0,3(LXC4+_03G$=4N#^@%^1KL!````ZQ8/'P!D2(L$
M)0````!(`P608P``3(LX2(GN3(G_@\,!Z,?$__\Y'?%U``!_UV1(BP0E````
M`$@#!6=C``!,BSBY`P```+H!````2(TU/P4``$R)_^BCQ/__2(G#2(7`=#U(
MBT`03(L@9$B+!"4`````2`,%+&,``$B-%1,%``!,B>9(BSA(B<7HG\3__TB+
M0Q!(BS#V1@Y`#X6!`0``9$B+!"4`````2`,%]F(``+D#````N@$```!(C378
M!```2(LX2(G%Z#+$__](B<-(A<!T+DB+-"1(C3UP`P``,<#H2.#__TB)PDB%
MP`^$%`$``$B+0Q!(BWT`2(LPZ"S$__]D2(L$)0````!(`P648@``N@$```!(
MC35]!```2(LX2(G#Z`7#__](BSM(C15]!```2(G&Z//#__](BP-(BS0D2(T]
M_0(``,:`L0`````QP.C7W___2(D%R'0``$B)PTB%P'1(OL`!``!(B=_H.\;_
M_XU0`8/Z`78)@_@1#X6P````2(M$)!AD2"L$)2@````/A9<```!(@\0H6UU!
M7$%=05Y!7\,/'X``````2(L]870``.C$\/__2(D%970``$B)PTB%P'6=2(T]
MA@0``#'`Z"?%__\/'X``````@'@!``^$!OW__^GG_/__D$2-8P&-0O]!.<0/
MA43^___I]/W__P\?`$B+!0ET``!(BS!(BT,02(LXZ#+D___IX?[__TB+?0#H
M=,3__^EQ_O__Z'K$__^)P4B+!=ES``!(B=I(C3TW!```2(LP,<#HK<3__V9F
M+@\?A```````9I!54TB)^TB#[`CH,NC__TB)Q^CZY___2(G%,<#H4.[__TB%
MVW0AA<!T'8`[`'08N@0```!(C36S`@``2(GOZ!["__^%P'0*2(/$"%M=PP\?
M`$B#Q`A(B=];7>G2W___9I#S#Q[Z2(L-!6,``.G0P?__\P\>^DB#[`A(@\0(
MPP``````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`4UE35$5-`"]T;7``
M5$5-4$1)4@!435``55-%4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`
M4$%42`!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%
M4E-)3TX`,2XP-#4`+64`+2T````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P<F]G;F%M
M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E
M<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q
M=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z
M.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I
M;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@
M*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@
M)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS
M,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G
M=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O
M<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN
M="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD
M=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^
M+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*
M;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M
M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*
M26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z
M.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T
M(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T:%]S97`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@
M("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X
M92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O
M(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?
M=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@)'!R;V=N
M86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@)'-I>F4@
M/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I9'@@/2`M
M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S970@/B`D
M<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS965K(&9A
M:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R96%D(%]&
M2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N("(D<')O
M9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD:61X(#T@
M<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED>"`^/2`P
M('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J(#$P,C0[
M"B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`["B1O9F9S
M970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*<F5A9"!?
M1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C:R@B3B(L
M("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E
M;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD
M4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64[
M"GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I
M;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I
M;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B4TA,24(Z
M("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@
M7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N86UE+3Y[
M8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D:64@(F-A
M;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN
M9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D
M97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]
M("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#
M>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D
M9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*
M?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I
M=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD
M9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B
M.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S
M.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E
M;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M
M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D
M14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@
M97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@
M/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI
M;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@
M*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%2
M1U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E
M('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H
M:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V
M72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T
M;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R
M(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H
M)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q
M("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@
M>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G
M9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A
M(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]
M"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D
M("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X*C$P,C0I
M.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@
M)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I
M;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&
M<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E
M96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*
M)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H
M+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R
M*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I
M;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE
M<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]
M("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E
M96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`
M<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*
M9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@
M)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@
M/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME
M>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V
M86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@
M+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*
M)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I
M('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`
M:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G
M<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@
M86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.
M0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID
M;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@
M)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C
M:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R
M96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y
M.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@
M*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-
M;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I
M.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M
M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S
M(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X
M="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%
M)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_
M("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E
M;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69]
M.PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG
M="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@
M/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE
M=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!
M5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I
M;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD
M9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T
M:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B
M+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE
M"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D[
M"B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(
M86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM
M92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T
M+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH
M;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_
M("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B
M7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@
M+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I
M;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD
M9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W
M-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R
M=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A
M=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0[
M"G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH
M9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C
M:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]4
M14U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O
M<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@
M)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB
M97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z
M)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY
M("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P
M96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII
M9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E
M<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B
M('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI]
M(&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@
M(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D
M9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q
M(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;
M("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R
M(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R
M8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]
M('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@
M/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@
M)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M
M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z
M.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE
M<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@
M;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q
M=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*
M<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R
M<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E
M<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E
M($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG
M.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I
M<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U
M:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES
M=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE
M=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*
M979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E
M($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z
M.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[
M(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F
M."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R
M7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P
M("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0
M(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S
M<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY
M("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W
M=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE
M.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U
M:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%
M3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G
M.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P
M<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I
M.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*
M:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y
M<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I
M<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*96QS92![
M"FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T
M.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!
M,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E
M<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*:68@*"1S
M:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y
M)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA
M;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO
M<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H
M92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["GT*
M8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T
M;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%2
M7U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T
M.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6
M>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXG
M+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA;64Z("0A
M(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L;W-E("1F
M:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR
M96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA
M;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@
M>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%2
M7U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R
M;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D
M<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]
M('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[
M7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I
M;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII9B`H
M;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D
M9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD<')O
M9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M
M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?9&5L
M:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)$-O
M;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B
M(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?
M4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#
M=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I
M;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M
M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N
M9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64[
M"GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)
M6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)
M5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@
M1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L971E
M("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!
M3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"
M04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["GT*
M;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@
M("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM005)?
M0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!
M3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@;&5N
M9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A;'5E
M(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T=7)N
M(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB
M.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR
M97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP
M('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L
M:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T
M($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S
M*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R
M;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE<W,@
M+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF
M("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*
M?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF
M("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z
M.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``````'!E<FQX
M<VDN8P````````#_____`````/____\`````7U]%3E9?4$%27T-,14%.7U\@
M("`@("`@("`@("`@("`!(T5G`````(FKS>\`````_MRZF`````!V5#(0````
M`/#ATL,````````````````!&P,[U````!D```"@@/__&`$``&"$__\$!@``
M8(;___````"0AO__!`$``%"'__]``0``P)W__Y`!``"0GO__W`$``""?__\`
M`@``D*#__SP"``#@HO__B`(``,"C___$`@```*3__]P"``!`I/__^`(```"E
M__\D`P``$*7__S@#````I___F`,``#"G__^L`P``$*C__]0#``!@K?__)`0`
M`."M__]`!````*[__U@$```0K___M`0```"[__^$!0``\+[__]`%``!0O___
M,`8````````4``````````%Z4@`!>!`!&PP'")`!```0````'````&B%__\F
M`````$0'$!`````P````A(7__P4`````````)````$0```"`?___P`,````.
M$$8.&$H/"W<(@``_&CLJ,R0B`````$P```!L````"(;__VH6````0@X0CP))
M#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[0!0-"%@H..$$.,$$.*$(.($(.
M&$(.$$(."$$+````2````+P````HG/__S`````!"#A"/`D(.&(X#0@X@C01"
M#BB,!4$.,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+`"``
M```(`0``K)S__X,`````00X0@P)*#K`!`G$*#A!!#@A!"S@````L`0``&)W_
M_VP!````0@X0C0)"#AB,`T$.((8$00XH@P5'#M`!?@H.*$$.($$.&$(.$$(.
M"$<+`$@```!H`0``3)[__T$"````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&
M!D0..(,'1PY@`Q4!"@XX00XP00XH0@X@0@X80@X00@X(10LX````M`$``%"@
M___@`````$(.$(T"1PX8C`-!#B"&!$0.*(,%40[`(`)L"@XH00X@00X80@X0
M0@X(1PL4````\`$``/2@__\U`````$0.$&P."``8````"`(``!RA__]`````
M`$$.$(,"9@X(````*````"0"``!`H?__N@````!!#A"&`D$.&(,#1P[`0`*F
M"@X81`X000X(00L0````4`(``-2A__\%`````````%P```!D`@``T*'__^(!
M````0@X0CP)"#AB.`T(.((T$0@XHC`5+#C"&!D0..(,'1P[P(0)D"@XX00XP
M00XH0@X@0@X80@X00@X(1`L"G0[X(4D.@")=#O@A00[P(0```!````#$`@``
M8*/__R4`````````)````-@"``!\H___U`````!*#A"#`@*/"@X(1PM("L,.
M"$@+3<,."$P``````P``-*3__U`%````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D@..(,'1`Z``0/;!`H..$$.,$$.*$(.($(.&$(.$$(."$$+````&```
M`%`#```TJ?__=`````!$#B!M"@X(1PL``!0```!L`P``F*G__QT`````1`X0
M6`X(`%@```"$`P``H*G__PL!````0@X0C0)"#AB,`T@.((8$1PXH@P5$#D`"
M0@H.*$8.($$.&$(.$$(."$P+9`H.*$$.($$.&$(.$$(."$8+80Y(20Y08PY(
M00Y`````S````.`#``!4JO__\`L```!"#A"/`E,.&(X#50X@C01"#BB,!4$.
M,(8&00XX@P='#N"#`@/R`0[H@P)A#O"#`F`.Z(,"0@[@@P("BPH..$0.,$$.
M*$(.($(.&$(.$$(."$8+`Y@!#NB#`DL.\(,"7@[H@P)!#N"#`ET.Z(,"1`[P
M@P)1#OB#`DL.@(0"2P[@@P("C`H..$0.,$$.*$(.($(.&$(.$$(."$4+`\8$
M#NB#`D(.\(,":`[H@P)!#N"#`@,J`0H.Z(,"0@[P@P)+"T@```"P!```=+7_
M_^,#````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1`Y@`R`#"@XX
M00XP00XH0@X@0@X80@X00@X(2`LP````_`0``!BY__]>`````$$.$(8"00X8
M@P-'#B`"00H.&$$.$$$."$0+1`X81`X000X(*````#`%``!4?O___`$```!!
M#A"&`D$.&(,#1`Y0`Y\!"@X80PX000X(00L0````7`4``!BY__\0````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#`)D```````)`F0````````0`````````4`P``````
M``$`````````)@,````````!`````````#`#`````````0`````````Z`P``
M``````$`````````3P,````````/`````````,`$````````#```````````
M($````````T`````````X%Y````````9`````````&"]0```````&P``````
M```(`````````!H`````````:+U````````<``````````@`````````]?[_
M;P````#``T````````4`````````4`U````````&`````````(`$0```````
M"@````````#[!`````````L`````````&``````````5````````````````
M`````P````````#HOT````````(`````````B`4````````4``````````<`
M````````%P````````"P%$````````<`````````J!-````````(````````
M``@!````````"0`````````8`````````/[__V\`````"!-```````#___]O
M``````(`````````\/__;P````!,$D``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````!PO4``````````````
M```````````````V($```````$8@0```````5B!```````!F($```````'8@
M0```````AB!```````"6($```````*8@0```````MB!```````#&($``````
M`-8@0```````YB!```````#V($````````8A0```````%B%````````F(4``
M`````#8A0```````1B%```````!6(4```````&8A0```````=B%```````"&
M(4```````)8A0```````IB%```````"V(4```````,8A0```````UB%`````
M``#F(4```````/8A0```````!B)````````6(D```````"8B0```````-B)`
M``````!&(D```````%8B0```````9B)```````!V(D```````(8B0```````
MEB)```````"F(D```````+8B0```````QB)```````#6(D```````.8B0```
M````]B)````````&(T```````!8C0```````)B-````````V(T```````$8C
M0```````5B-```````!F(T```````'8C0```````AB-```````"6(T``````
M`*8C0```````MB-```````#&(T```````-8C0```````````````````````
M`````/____\`````V&)```````!'0T,Z("A03$0M3&EN=7@I(#$S+C(N,"`R
M,#(S,#<R-R`H<F5L96%S92D`1T-#.B`H4$Q$+4QI;G5X*2`Q,RXS+C`@,C`R
M-#`U,C$@*')E;&5A<V4I```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M<')O<&5R='D`+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N
M=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S
M:6]N7W(`+G)E;&$N9'EN`"YR96QA+G!L=``N:6YI=``N=&5X=``N9FEN:0`N
M<F]D871A`"YE:%]F<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N
M8V]M;65N=```````````````````````````````````````````````````
M``````````````````````````````````````````L````!`````@``````
M```8`T```````!@#````````'`````````````````````$`````````````
M```````3````!P````(`````````.`-````````X`P```````$``````````
M```````````(````````````````````)@````<````"`````````'@#0```
M````>`,````````D````````````````````!````````````````````#D`
M```'`````@````````"<`T```````)P#````````(```````````````````
M``0```````````````````!'````]O__;P(`````````P`-```````#``P``
M`````+P`````````!@`````````(````````````````````40````L````"
M`````````(`$0```````@`0```````#0"`````````<````!````"```````
M```8`````````%D````#`````@````````!0#4```````%`-````````^P0`
M``````````````````$```````````````````!A````____;P(`````````
M3!)```````!,$@```````+P`````````!@`````````"``````````(`````
M````;@```/[__V\"``````````@30```````"!,```````"@``````````<`
M```"````"````````````````````'T````$`````@````````"H$T``````
M`*@3````````"`$````````&``````````@`````````&`````````"'````
M!````$(`````````L!1```````"P%````````(@%````````!@```!<````(
M`````````!@`````````D0````$````&```````````@0````````"``````
M```;````````````````````!````````````````````(P````!````!@``
M```````@($```````"`@````````P`,``````````````````!``````````
M$`````````"7`````0````8`````````X"-```````#@(P`````````[````
M```````````````0````````````````````G0````$````&`````````.!>
M0```````X%X````````-````````````````````!```````````````````
M`*,````!`````@``````````8$````````!@````````@#\`````````````
M`````!````````````````````"K`````0````(`````````@)]```````"`
MGP```````-0````````````````````$````````````````````N0````$`
M```"`````````%B@0```````6*````````!P!0``````````````````"```
M`````````````````,,````.`````P````````!@O4```````&"M````````
M"`````````````````````@`````````"`````````#/````#P````,`````
M````:+U```````!HK0````````@````````````````````(``````````@`
M````````VP````8````#`````````'"]0```````<*T````````@`@``````
M``<`````````"``````````0`````````.0````!`````P````````"0OT``
M`````)"O````````6`````````````````````@`````````"`````````#I
M`````0````,`````````Z+]```````#HKP```````/`!````````````````
M```(``````````@`````````\@````$````#`````````-C!0```````V+$`
M```````@````````````````````"````````````````````/@````(````
M`P``````````PD```````/BQ````````2!```````````````````"``````
M``````````````#]`````0```#````````````````````#XL0```````%8`
M```````````````````!``````````$``````````0````,`````````````
M````````````3K(````````&`0```````````````````0``````````````
$````````
